using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.EntityFrameworkCore;
using WebApplication1.Models;

namespace WebApplication1.Repositories
{
    public class PurchaseInformationRepository
    {
        private readonly DbContext _context;

        public PurchaseInformationRepository(DbContext context)
        {
            _context = context;
        }

        // 1-2.仕入先のリスト情報を仕入先マスタから全件取得し、仕入先の選択肢として設定する。
        public async Task<List<MST_SUPPLIERModel>> GetAllSuppliersAsync()
        {
            return await _context.Set<MST_SUPPLIERModel>().ToListAsync();
        }

        // 1-3.仕入担当者のリスト情報を担当者マスタから全件取得し、仕入先担当者の選択肢として設定する。
        public async Task<List<MST_PERSONModel>> GetAllPersonsAsync()
        {
            return await _context.Set<MST_PERSONModel>().ToListAsync();
        }

        // 1-6.商品種別のリスト情報を商品種別マスタから全件取得し、商品種別の選択肢として設定する。
        public async Task<List<MST_ITEM_CATEGORYModel>> GetAllItemCategoriesAsync()
        {
            return await _context.Set<MST_ITEM_CATEGORYModel>().ToListAsync();
        }

        // 2-3.仕入情報と仕入先マスタと担当者マスタと商品マスタ、商品種別マスタを結合し、ソート順は仕入先コード、仕入日として仕入情報を取得する。
        public async Task<List<PURCHASE_INFORMATIONModel>> GetPurchaseInformationAsync(
            string supplierCode, string personCode, DateTime? startDate, DateTime? endDate, 
            string itemCategory, string itemName)
        {
            var query = _context.Set<PURCHASE_INFORMATIONModel>().AsQueryable();

            if (!string.IsNullOrEmpty(supplierCode))
                query = query.Where(x => x.SUPPLIER_CODE == supplierCode);

            if (!string.IsNullOrEmpty(personCode))
                query = query.Where(x => x.PURCHASE_PIC == personCode);

            if (startDate.HasValue)
                query = query.Where(x => x.PURCHASE_DATE >= startDate.Value);

            if (endDate.HasValue)
                query = query.Where(x => x.PURCHASE_DATE <= endDate.Value);

            if (!string.IsNullOrEmpty(itemCategory))
                query = query.Where(x => x.ITEM_CODE.StartsWith(itemCategory)); // Assuming ITEM_CODE starts with ITEM_CATEGORY

            if (!string.IsNullOrEmpty(itemName))
                query = query.Where(x => x.ITEM_CODE == itemName); // Assuming ITEM_CODE is equivalent to itemName

            return await query.OrderBy(x => x.SUPPLIER_CODE).ThenBy(x => x.PURCHASE_DATE).ToListAsync();
        }

        // 2-4.画面項目名の小計金額に前記で取得した仕入情報をループし、仕入先毎に(仕入単価×仕入数量)を集計し、仕入先毎に集計した結果値を表示する。
        public async Task<Dictionary<string, decimal>> CalculateSubtotalBySupplierAsync(List<PURCHASE_INFORMATIONModel> purchases)
        {
            return purchases
                .GroupBy(x => x.SUPPLIER_CODE)
                .ToDictionary(
                    group => group.Key,
                    group => group.Sum(x => x.PURCHASE_UNIT_PRICE * x.PURCHASE_QUANTITY)
                );
        }

        // 2-5.画面項目名の合計金額に前記で取得した仕入情報をループし、全ての(仕入単価×仕入数量)を集計し、集計した結果値を表示する。
        public async Task<decimal> CalculateTotalAmountAsync(List<PURCHASE_INFORMATIONModel> purchases)
        {
            return purchases.Sum(x => x.PURCHASE_UNIT_PRICE * x.PURCHASE_QUANTITY);
        }
    }
}