using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using WebApplication1.Models;
using WebApplication1.Repositories;

namespace WebApplication1.Services
{
    public class PurchaseInformationService
    {
        private readonly PurchaseInformationRepository _repository;

        public PurchaseInformationService(PurchaseInformationRepository repository)
        {
            _repository = repository;
        }

        // 1-1.本画面の使用権限があるか確認する（共通部品を参照）
        public async Task<bool> CheckUserPermissionAsync()
        {
            // 権限チェックの共通部品を呼び出す想定
            return await Task.FromResult(true); // 仮実装
        }

        // 2-1.仕入開始日、仕入終了日のどちらも入力されていない場合は「検索条件を指定してください。」とエラーメッセージを返却する。
        public string ValidateSearchConditions(DateTime? startDate, DateTime? endDate)
        {
            if (!startDate.HasValue && !endDate.HasValue)
                return "検索条件を指定してください。";

            if (startDate.HasValue && endDate.HasValue && startDate > endDate)
                return "仕入日の検索条件の指定に誤りがあります。";

            return null;
        }

        // 2-3.仕入情報の検索処理
        public async Task<(List<PURCHASE_INFORMATIONModel> PurchaseInformationList, string ErrorMessage)> SearchPurchaseInformationAsync(
            string supplierCode, string personCode, DateTime? startDate, DateTime? endDate, 
            string itemCategory, string itemName)
        {
            var errorMessage = ValidateSearchConditions(startDate, endDate);
            if (errorMessage != null)
                return (null, errorMessage);

            var purchaseInformationList = await _repository.GetPurchaseInformationAsync(
                supplierCode, personCode, startDate, endDate, itemCategory, itemName);

            if (purchaseInformationList.Count == 0)
                return (null, "検索結果が存在しませんでした。");

            return (purchaseInformationList, null);
        }

        // 2-4.小計金額の計算処理
        public async Task<Dictionary<string, decimal>> CalculateSubtotalBySupplierAsync(List<PURCHASE_INFORMATIONModel> purchases)
        {
            return await _repository.CalculateSubtotalBySupplierAsync(purchases);
        }

        // 2-5.合計金額の計算処理
        public async Task<decimal> CalculateTotalAmountAsync(List<PURCHASE_INFORMATIONModel> purchases)
        {
            return await _repository.CalculateTotalAmountAsync(purchases);
        }
    }
}