package com.example.entity;

import lombok.Data;
import javax.persistence.*;
import java.util.Date;

/**
 * 仕入情報エンティティ
 */
@Entity
@Table(name = "PURCHASE_INFORMATION")
@Data
public class PurchaseInformationEntity {

    /**
     * 仕入番号 (PK)
     */
    @Id
    @Column(name = "PURCHASE_NO", nullable = false)
    private Long purchaseNo;

    /**
     * 仕入日
     */
    @Column(name = "PURCHASE_DATE", nullable = false)
    @Temporal(TemporalType.DATE)
    private Date purchaseDate;

    /**
     * 仕入先コード
     */
    @ManyToOne
    @JoinColumn(name = "SUPPLIER_CODE", referencedColumnName = "SUPPLIER_CODE", nullable = false)
    private MstSupplierEntity supplierCode;

    /**
     * 商品コード
     */
    @ManyToOne
    @JoinColumn(name = "ITEM_CODE", referencedColumnName = "ITEM_CODE", nullable = false)
    private MstItemEntity itemCode;

    /**
     * 仕入単価
     */
    @Column(name = "PURCHASE_UNIT_PRICE", nullable = false)
    private Integer purchaseUnitPrice;

    /**
     * 仕入数量
     */
    @Column(name = "PURCHASE_QUANTITY", nullable = false)
    private Integer purchaseQuantity;

    /**
     * 仕入担当者
     */
    @ManyToOne
    @JoinColumn(name = "PURCHASE_PIC", referencedColumnName = "PERSON_CODE", nullable = false)
    private MstPersonEntity purchasePic;

    /**
     * 登録者
     */
    @Column(name = "REGIST_PERSON", length = 5)
    private String registPerson;

    /**
     * 登録日時
     */
    @Column(name = "REGIST_DATETIME")
    @Temporal(TemporalType.TIMESTAMP)
    private Date registDatetime;

    /**
     * 更新者
     */
    @Column(name = "EDIT_PERSON", length = 5)
    private String editPerson;

    /**
     * 更新日時
     */
    @Column(name = "EDIT_DATETIME")
    @Temporal(TemporalType.TIMESTAMP)
    private Date editDatetime;
}