package com.example.repository;

import com.example.entity.PurchaseInformationEntity;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;

import java.util.Date;
import java.util.List;

/**
 * 仕入情報リポジトリ
 */
public interface PurchaseInformationRepository extends JpaRepository<PurchaseInformationEntity, Long> {

    /**
     * 検索条件に基づいて仕入情報を取得するクエリ
     * 
     * @param supplierCode 仕入先コード
     * @param purchasePic 仕入担当者
     * @param startDate 仕入開始日
     * @param endDate 仕入終了日
     * @param itemCategory 商品種別
     * @param itemName 商品名
     * @return 検索結果の仕入情報リスト
     */
    @Query("SELECT pi FROM PurchaseInformationEntity pi " +
           "JOIN pi.supplierCode s " +
           "JOIN pi.itemCode i " +
           "JOIN pi.purchasePic p " +
           "WHERE (:supplierCode IS NULL OR s.supplierCode = :supplierCode) " +
           "AND (:purchasePic IS NULL OR p.personCode = :purchasePic) " +
           "AND (:startDate IS NULL OR pi.purchaseDate >= :startDate) " +
           "AND (:endDate IS NULL OR pi.purchaseDate <= :endDate) " +
           "AND (:itemCategory IS NULL OR i.itemCategory.itemCategory = :itemCategory) " +
           "AND (:itemName IS NULL OR i.itemName LIKE %:itemName%) " +
           "ORDER BY s.supplierCode, pi.purchaseDate")
    List<PurchaseInformationEntity> findBySearchCriteria(
            @Param("supplierCode") String supplierCode,
            @Param("purchasePic") String purchasePic,
            @Param("startDate") Date startDate,
            @Param("endDate") Date endDate,
            @Param("itemCategory") String itemCategory,
            @Param("itemName") String itemName);
}