package com.example.service;

import com.example.entity.PurchaseInformationEntity;
import com.example.repository.PurchaseInformationRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.List;

/**
 * 仕入情報サービス
 */
@Service
@Transactional
public class PurchaseInformationService {

    @Autowired
    private PurchaseInformationRepository purchaseInformationRepository;

    /**
     * 検索条件に基づいて仕入情報を取得する
     * 
     * @param supplierCode 仕入先コード
     * @param purchasePic 仕入担当者
     * @param startDate 仕入開始日
     * @param endDate 仕入終了日
     * @param itemCategory 商品種別
     * @param itemName 商品名
     * @return 検索結果の仕入情報リスト
     */
    public List<PurchaseInformationEntity> searchPurchaseInformation(
            String supplierCode,
            String purchasePic,
            Date startDate,
            Date endDate,
            String itemCategory,
            String itemName) {
        return purchaseInformationRepository.findBySearchCriteria(
                supplierCode, purchasePic, startDate, endDate, itemCategory, itemName);
    }
}