from django.db import models

class ItemCategory(models.Model):
    # 商品種別マスタ
    item_category = models.CharField(max_length=3, primary_key=True, db_column='ITEM_CATEGORY')
    item_category_name = models.CharField(max_length=50, db_column='ITEM_CATEGORY_NAME')
    regist_person = models.CharField(max_length=5, db_column='REGIST_PERSON')
    regist_datetime = models.DateTimeField(db_column='REGIST_DATETIME')
    edit_person = models.CharField(max_length=5, db_column='EDIT_PERSON')
    edit_datetime = models.DateTimeField(db_column='EDIT_DATETIME')

    class Meta:
        db_table = 'MST_ITEM_CATEGORY'

class Item(models.Model):
    # 商品マスタ
    item_code = models.CharField(max_length=13, primary_key=True, db_column='ITEM_CODE')
    item_name = models.CharField(max_length=100, db_column='ITEM_NAME')
    item_short_name = models.CharField(max_length=50, db_column='ITEM_SHORT_NAME')
    item_category = models.ForeignKey(ItemCategory, on_delete=models.CASCADE, db_column='ITEM_CATEGORY')
    regist_person = models.CharField(max_length=5, db_column='REGIST_PERSON')
    regist_datetime = models.DateTimeField(db_column='REGIST_DATETIME')
    edit_person = models.CharField(max_length=5, db_column='EDIT_PERSON')
    edit_datetime = models.DateTimeField(db_column='EDIT_DATETIME')

    class Meta:
        db_table = 'MST_ITEM'

class Person(models.Model):
    # 担当者マスタ
    person_code = models.CharField(max_length=5, primary_key=True, db_column='PERSON_CODE')
    person_name = models.CharField(max_length=100, db_column='PERSON_NAME')
    person_division = models.CharField(max_length=50, db_column='PERSON_DIVISION')
    person_phone_no = models.CharField(max_length=15, db_column='PERSON_PHON_NO')
    regist_person = models.CharField(max_length=5, db_column='REGIST_PERSON')
    regist_datetime = models.DateTimeField(db_column='REGIST_DATETIME')
    edit_person = models.CharField(max_length=5, db_column='EDIT_PERSON')
    edit_datetime = models.DateTimeField(db_column='EDIT_DATETIME')

    class Meta:
        db_table = 'MST_PERSON'

class Supplier(models.Model):
    # 仕入先マスタ
    supplier_code = models.CharField(max_length=4, primary_key=True, db_column='SUPPLIER_CODE')
    supplier_name = models.CharField(max_length=100, db_column='SUPPLIER_NAME')
    supplier_short_name = models.CharField(max_length=50, db_column='SUPPLIER_SHORT_NAME')
    supplier_phone_no = models.CharField(max_length=15, db_column='SUPPLIER_PHONE_NO')
    supplier_pic = models.CharField(max_length=100, db_column='SUPPLIER_PIC')
    regist_person = models.CharField(max_length=5, db_column='REGIST_PERSON')
    regist_datetime = models.DateTimeField(db_column='REGIST_DATETIME')
    edit_person = models.CharField(max_length=5, db_column='EDIT_PERSON')
    edit_datetime = models.DateTimeField(db_column='EDIT_DATETIME')

    class Meta:
        db_table = 'MST_SUPPLIER'

class PurchaseInformation(models.Model):
    # 仕入情報
    purchase_no = models.AutoField(primary_key=True, db_column='PURCHASE_NO')
    purchase_date = models.DateField(db_column='PURCHASE_DATE')
    supplier_code = models.ForeignKey(Supplier, on_delete=models.CASCADE, db_column='SUPPLIER_CODE')
    item_code = models.ForeignKey(Item, on_delete=models.CASCADE, db_column='ITEM_CODE')
    purchase_unit_price = models.DecimalField(max_digits=10, decimal_places=2, db_column='PURCHASE_UNIT_PRICE')
    purchase_quantity = models.IntegerField(db_column='PURCHASE_QUANTITY')
    purchase_pic = models.ForeignKey(Person, on_delete=models.CASCADE, db_column='PURCHASE_PIC')
    regist_person = models.CharField(max_length=5, db_column='REGIST_PERSON')
    regist_datetime = models.DateTimeField(db_column='REGIST_DATETIME')
    edit_person = models.CharField(max_length=5, db_column='EDIT_PERSON')
    edit_datetime = models.DateTimeField(db_column='EDIT_DATETIME')

    class Meta:
        db_table = 'PURCHASE_INFORMATION'